from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.2.3'
DESCRIPTION = 'Cerebra is an AI Orchestrator for LLM models.'

# Setting up
setup(
    name="cerebraai",
    version=VERSION,
    author="Juan Pablo Gutiérrez",
    author_email="<58833781+jpgtzg@users.noreply.github.com>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[
        'annotated-types>=0.7.0',
        'anyio>=4.8.0',
        'backports.tarfile>=1.2.0',
        'build>=1.2.2.post1',
        'CacheControl>=0.14.2',
        'certifi>=2024.12.14',
        'cffi>=1.17.1',
        'charset-normalizer>=3.4.1',
        'cleo>=2.1.0',
        'click>=8.1.8',
        'contourpy>=1.3.1',
        'crashtest>=0.4.1',
        'cycler>=0.12.1',
        'distlib>=0.3.9',
        'distro>=1.9.0',
        'dulwich>=0.22.7',
        'emoji>=1.7.0',
        'exceptiongroup>=1.2.2',
        'fastjsonschema>=2.21.1',
        'filelock>=3.16.1',
        'fonttools>=4.55.3',
        'fsspec>=2024.12.0',
        'h11>=0.14.0',
        'httpcore>=1.0.7',
        'httpx>=0.28.1',
        'huggingface-hub>=0.27.0',
        'idna>=3.10',
        'importlib_metadata>=8.5.0',
        'installer>=0.7.0',
        'jaraco.classes>=3.4.0',
        'jaraco.context>=6.0.1',
        'jaraco.functools>=4.1.0',
        'Jinja2>=3.1.5',
        'jiter>=0.8.2',
        'joblib>=1.4.2',
        'keyring>=25.6.0',
        'kiwisolver>=1.4.8',
        'MarkupSafe>=3.0.2',
        'matplotlib>=3.10.0',
        'more-itertools>=10.5.0',
        'mpmath>=1.3.0',
        'msgpack>=1.1.0',
        'networkx>=3.4.2',
        'nltk>=3.5',
        'numpy>=2.2.1',
        'packaging>=24.2',
        'pillow>=11.1.0',
        'pkginfo>=1.12.0',
        'platformdirs>=4.3.6',
        'poetry>=2.0.0',
        'poetry-core>=2.0.0',
        'pycparser>=2.22',
        'pydantic>=2.10.4',
        'pydantic_core>=2.27.2',
        'pyparsing>=3.2.1',
        'pyproject_hooks>=1.2.0',
        'python-dateutil>=2.9.0.post0',
        'python-dotenv>=1.0.1',
        'PyYAML>=6.0.2',
        'RapidFuzz>=3.11.0',
        'regex>=2024.11.6',
        'requests>=2.32.3',
        'requests-toolbelt>=1.0.0',
        'safetensors>=0.5.0',
        'scikit-fuzzy>=0.5.0',
        'scikit-learn>=1.6.0',
        'scipy>=1.15.0',
        'sentence-transformers>=3.3.1',
        'shellingham>=1.5.4',
        'six>=1.17.0',
        'sniffio>=1.3.1',
        'sympy>=1.13.1',
        'text2emotion>=0.0.5',
        'threadpoolctl>=3.5.0',
        'tiktoken>=0.8.0',
        'tokenizers>=0.21.0',
        'tomli>=2.2.1',
        'tomlkit>=0.13.2',
        'torch>=2.5.1',
        'tqdm>=4.67.1',
        'transformers>=4.47.1',
        'trove-classifiers>=2025.1.7.14',
        'typing_extensions>=4.12.2',
        'urllib3>=2.3.0',
        'virtualenv>=20.28.1',
        'xattr>=1.1.4',
        'zipp>=3.21.0'
    ],
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
